;OShell-82 version 1.0 & 1.1
;Assembly include file for TI-82 object assembling
;(C) 1997 Alphasoft, written by Jason Todd

#DEFINE ROM_CALL(INDEX) CALL $8D28 \ .DB INDEX  ; Access to ROM routines
#DEFINE CALL_Z(ADDR)    CALL $8D2B \ .DW ADDR   ; ALL programs USE THESE
#DEFINE CALL_(ADDR)     CALL $8D2E \ .DW ADDR   ;       instead of a normal
#DEFINE CALL_NZ(ADDR)   CALL $8D31 \ .DW ADDR   ;       CALL instruction
#DEFINE CALL_C(ADDR)    CALL $8D37 \ .DW ADDR   ;  "    "
#DEFINE CALL_NC(ADDR)   CALL $8D3D \ .DW ADDR   ;  "    "
#DEFINE JUMP_Z(ADDR)    CALL $8D43 \ .DW ADDR   ; Use these if the normal
#DEFINE JUMP_(ADDR)     CALL $8D46 \ .DW ADDR   ;       relative jump has too
#DEFINE JUMP_NZ(ADDR)   CALL $8D49 \ .DW ADDR   ;       far to go
#DEFINE JUMP_C(ADDR)    CALL $8D4F \ .DW ADDR   ;  "    "
#DEFINE JUMP_NC(ADDR)   CALL $8D55 \ .DW ADDR   ;  "    "

;TI-82 universal ROM routine addresses - same in all versions, use CALL
LD_HL_MHL       =$0033  ; HL=(HL), A=L
CP_HL_DE        =$0095  ; CP HL,DE (modifies flags only)
UNPACK_HL       =$00A1  ; Unpack one digit of HL into A (used in D_HL_DECI)
STORE_KEY       =$01C7  ; Store immediate keystroke from A
;NOTE:  I haven't yet been able to get any output from GET_KEY although the
;       immediate code at $01D4 is the same as the TI-85's GET_KEY routine...
;       Therefore, I suggest you use ROM_CALL(_getkey) which is the same as
;       the TI-83's _getkey routine...
GET_KEY         =$01D4  ; Get immediate keystroke into A

;OShell-82 1.1 Public data areas/variables
PROGRAM_ADDR    =$8D5B  ; RAM location of currently executing program
OS_VER          =$8D5D  ; OShell version number (top 4 bits = major version)
OS_BITS         =$8D5E  ; OShell status byte (currently only used internally)

;These names are reserved for the ROM_CALL() macro
TX_CHARPUT       =$00   ; Normal text display translated CHAR of A
CLEARLCD         =$08   ; Clear the LCD hardware only
D_HL_DECI        =$09   ; Normal text display right justified VALUE of HL
CLEARTEXT        =$0A   ; Set all the text memory to 00
D_ZT_STR         =$0B   ; Normal text display ASCIIZ string at HL
BUSY_OFF         =$0C   ; Turn off "busy" indicator
BUSY_ON          =$0D   ; Turn on "busy" indicator
_GETKEY          =$0E   ; Wait for and return getkey code (See KEYCODES.INC)
_GRBUFCPY_V      =$0F   ; Copies graph screen to LCD

;TI-82 RAM data areas/variables - I will expand on this later
KEY_0           =$8000  ; Translated scancode of last key, but 0 if gotten
LAST_KEY        =$8006  ; Last key pressed
CURSOR_ROW      =$800C  ; Normal text cursor row
CURSOR_COL      =$800D  ; Normal text cursor column
TEXT_MEM        =$808F  ; Text memory, 128 bytes
_IY_TABLE       =$8528  ; This is the default value of IY in the ROM
GRAPH_MEM       =$88B8  ; Graph memory buffer - used in ROM_CALL(_grbufcpy_v)
TEXT_MEM2       =$8BDF  ; Secondary text memory, 128 bytes
VAT_START       =$FE6F  ; Beginning of VAT (works backwards)
STACK           =$FFFF  ; Beginning of STACK (also works backwards)

;TI-82 Hardware I/O Ports - USE AT YOUR OWN RISK
LINKPORT        =$00    ; Same functionality as the TI-85 port
KEYPAD          =$01    ; Same as TI-85
MISCPORT        =$02    ; ROM page switching, other functions...
LCDPOWER        =$03    ; Same as TI-85
MISCPORT2       =$04    ; Apparently same as TI-85 port
LCDINSTPORT     =$10    ; Apparently same as TI-83 port
LCDDATAPORT     =$11    ; Not much info on this one (TI-83?)

;Codes returned by ROM_CALL(_getkey)
;Refer to KEYCODES.INC for a complete list
K_ON            =$00    ; NOTE:  You will have to RES 4,(IY+09) after pressed
R_ARROW         =$01
L_ARROW         =$02
U_ARROW         =$03
D_ARROW         =$04
K_ENTER         =$05
K_CLEAR         =$06
K_QUIT          =$40    ; [2nd] [MODE]/QUIT
